package com.xtd.project.assets.mapper;

import java.util.List;
import com.xtd.project.assets.domain.DbTableHis;

/**
 * 流程历史单Mapper接口
 * 
 * @author xtd
 * @date 2020-04-14
 */
public interface DbTableHisMapper 
{
    /**
     * 查询流程历史单
     * 
     * @param instanceId 流程历史单ID
     * @return 流程历史单
     */
    public DbTableHis selectDbTableHisById(String instanceId);

    /**
     * 查询流程历史单列表
     * 
     * @param dbTableHis 流程历史单
     * @return 流程历史单集合
     */
    public List<DbTableHis> selectDbTableHisList(DbTableHis dbTableHis);

    /**
     * 新增流程历史单
     * 
     * @param dbTableHis 流程历史单
     * @return 结果
     */
    public int insertDbTableHis(DbTableHis dbTableHis);

    /**
     * 修改流程历史单
     * 
     * @param dbTableHis 流程历史单
     * @return 结果
     */
    public int updateDbTableHis(DbTableHis dbTableHis);

    /**
     * 删除流程历史单
     * 
     * @param instanceId 流程历史单ID
     * @return 结果
     */
    public int deleteDbTableHisById(String instanceId);

    /**
     * 批量删除流程历史单
     * 
     * @param instanceIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteDbTableHisByIds(String[] instanceIds);
}
